==> respec-17.1.1.tgz: package/README.md <==
# ReSpec

[![Greenkeeper badge](https://badges.greenkeeper.io/w3c/respec.svg)](https://greenkeeper.io/)

[![Build Status](https://travis-ci.org/w3c/respec.svg?branch=develop)](https://travis-ci.org/w3c/respec)
[![Known Vulnerabilities](https://snyk.io/test/github/w3c/respec/badge.svg)](https://snyk.io/test/github/w3c/respec)

ReSpec is a JS library that makes it easier to write technical specifications, or documents
that tend to be technical in nature in general. It was originally designed for the purpose
of writing W3C specifications, but has since grown to be able to support other outputs as
well.

## Getting started

If you are just interested in writing a spec, you can grab the [starter spec](examples/starter.html).

We have extensive documentation on [how to use ReSpec](https://github.com/w3c/respec/wiki) in our wiki, including:  

  * [User's guide](https://github.com/w3c/respec/wiki/User's-Guide)
  * [WebIDL guide](https://github.com/w3c/respec/wiki/WebIDL-Guide)

**You don't need to check-out or fork this repository.**

If you are new to spec writing, we strongly encourage you to read:

  * [API Design Principles](https://w3ctag.github.io/design-principles/)
  * [Writing Promise-Using Specifications](https://www.w3.org/2001/tag/doc/promises-guide)
  * [Privacy and Security Self-Review Questionnaire](https://w3ctag.github.io/security-questionnaire/)

## Getting help

If you experience issues, please email [spec-prod@w3.org](mailto:spec-prod@w3.org) or
if you think something is broken, [file a bug](https://github.com/w3c/respec/issues).

**Please note:** ReSpec is not endorsed by W3C and nobody should expect the W3C Webmaster to provide advice on
problems encountered with ReSpec, or on why it may be failing to produce pubrules-compliant
content.

## Bibliographical references

Bibliographical references have been moved out of ReSpec. You want to use
[specref.org](http://www.specref.org/).

## Want to see complete documentation?

[Documentation for ReSpec](https://github.com/w3c/respec/wiki) is available in our wiki.

## Contribute
Please note that this project is released with a [Contributor Code of Conduct](CODE_OF_CONDUCT.md). By participating in this project you agree to abide by its terms.

==> respec-22.5.2.tgz: package/README.md <==
# ReSpec

[![Greenkeeper badge](https://badges.greenkeeper.io/w3c/respec.svg)](https://greenkeeper.io/) [![Build Status](https://travis-ci.org/w3c/respec.svg?branch=develop)](https://travis-ci.org/w3c/respec) [![Known Vulnerabilities](https://snyk.io/test/github/w3c/respec/badge.svg)](https://snyk.io/test/github/w3c/respec)

ReSpec is a JS library that makes it easier to write technical specifications, or documents
that tend to be technical in nature in general. It was originally designed for the purpose
of writing W3C specifications, but has since grown to be able to support other outputs as
well.

## Getting started

If you are just interested in writing a spec, you can grab the [starter spec](examples/starter.html).

We have extensive documentation on [how to use ReSpec](https://github.com/w3c/respec/wiki) in our wiki, including:  

  * [User's guide](https://github.com/w3c/respec/wiki/ReSpec-Editor's-Guide)
  * [WebIDL guide](https://github.com/w3c/respec/wiki/WebIDL-Guide)

**You don't need to check-out or fork this repository.**

If you are new to spec writing, we strongly encourage you to read:

  * [API Design Principles](https://w3ctag.github.io/design-principles/)
  * [Writing Promise-Using Specifications](https://www.w3.org/2001/tag/doc/promises-guide)
  * [Privacy and Security Self-Review Questionnaire](https://w3ctag.github.io/security-questionnaire/)

## Getting help

If you experience issues, please email [spec-prod@w3.org](mailto:spec-prod@w3.org) or
if you think something is broken, [file a bug](https://github.com/w3c/respec/issues).

**Please note:** ReSpec is not endorsed by W3C and nobody should expect the W3C Webmaster to provide advice on
problems encountered with ReSpec, or on why it may be failing to produce pubrules-compliant
content.

## Bibliographical references

Bibliographical references have been moved out of ReSpec. You want to use
[specref.org](http://www.specref.org/).

## Want to see complete documentation?

[Documentation for ReSpec](https://github.com/w3c/respec/wiki) is available in our wiki.

## Contribute

Please see our [developer guide](https://github.com/w3c/respec/wiki/Developers-Guide). 

Please note that this project is released with a [Contributor Code of Conduct](CODE_OF_CONDUCT.md). By participating in this project you agree to abide by its terms.
